==> haskell-aeson-diff-1.1.0.7-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-diff
version: 1.1.0.7
id: aeson-diff-1.1.0.7-K84GMgNx3VXDN9Dsy4uRQC
key: aeson-diff-1.1.0.7-K84GMgNx3VXDN9Dsy4uRQC
license: BSD-3-Clause
copyright: (c) 2015 Thomas Sutton and others.
maintainer: me@thomas-sutton.id.au
author: Thomas Sutton
homepage: https://github.com/thsutton/aeson-diff
synopsis: Extract and apply patches to JSON documents.
description:
    .
    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.
    .
category: JSON, Web, Algorithms
abi: b61d96502a6de7cb970978e8bd199b96
exposed: True
exposed-modules:
    Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-diff-1.1.0.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-diff-1.1.0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/aeson-diff-1.1.0.7
hs-libraries: HSaeson-diff-1.1.0.7-K84GMgNx3VXDN9Dsy4uRQC
depends:
    aeson-1.4.4.0-7vLg8fT3jLZEAAmFwxYKHF base-4.12.0.0
    bytestring-0.10.8.2
    edit-distance-vector-1.0.0.4-IlPOoRNQu628qAguWW1KKb
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo mtl-2.2.2
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-1qvqZt81kSY49gkPLj6it0
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html: /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-diff-1.1.0.7-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-diff.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-diff
version: 1.1.0.7
id: aeson-diff-1.1.0.7-8bmtxxsvrXwJTfXC5ilHLq
key: aeson-diff-1.1.0.7-8bmtxxsvrXwJTfXC5ilHLq
license: BSD-3-Clause
copyright: (c) 2015 Thomas Sutton and others.
maintainer: me@thomas-sutton.id.au
author: Thomas Sutton
homepage: https://github.com/thsutton/aeson-diff
synopsis: Extract and apply patches to JSON documents.
description:
    .
    This is a small library for working with changes to JSON documents. It
    includes a library and two command-line executables in the style of the
    diff(1) and patch(1) commands available on many systems.
    .
category: JSON, Web, Algorithms
abi: 6eee62d46a3adf538d165d4a58e1a3a3
exposed: True
exposed-modules:
    Data.Aeson.Diff Data.Aeson.Patch Data.Aeson.Pointer
import-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-diff-1.1.0.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-diff-1.1.0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/aeson-diff-1.1.0.7
hs-libraries: HSaeson-diff-1.1.0.7-8bmtxxsvrXwJTfXC5ilHLq
depends:
    aeson-1.4.4.0-HZF4dQ7ymfT471uy0aBwyJ base-4.12.0.0
    bytestring-0.10.8.2
    edit-distance-vector-1.0.0.4-1ejLvDo6GBEpQmm6g2i8L
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo mtl-2.2.2
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-aeson-diff/html/aeson-diff.haddock
haddock-html: /usr/share/doc/haskell-aeson-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
